@@ -57,7 +57,6 @@ public:
 
     [[nodiscard]] int todayColumn() const;
 
-public:
     EventView *const mEventView;
     Agenda *const mAgenda;
     QTimer *mTimer = nullptr;
@@ -125,7 +124,7 @@ void MarcusBains::updateLocationRecalc(bool recalculate)
     int y = int(minutes * d->mAgenda->gridSpacingY() / minutesPerCell);
     int x = int(d->mAgenda->gridSpacingX() * todayCol);
 
-    bool hideIt = !(d->mEventView->preferences()->marcusBainsEnabled());
+    bool const hideIt = !(d->mEventView->preferences()->marcusBainsEnabled());
     if (!isHidden() && (hideIt || (todayCol < 0))) {
         hide();
         d->mTimeBox->hide();
@@ -193,28 +192,10 @@ public:
     AgendaPrivate(AgendaView *agendaView, QScrollArea *scrollArea, int columns, int rows, int rowSize, bool isInteractive)
         : mAgendaView(agendaView)
         , mScrollArea(scrollArea)
-        , mAllDayMode(false)
         , mColumns(columns)
         , mRows(rows)
-        , mGridSpacingX(0.0)
         , mGridSpacingY(rowSize)
         , mDesiredGridSpacingY(rowSize)
-        , mChanger(nullptr)
-        , mResizeBorderWidth(0)
-        , mScrollBorderWidth(0)
-        , mScrollDelay(0)
-        , mScrollOffset(0)
-        , mWorkingHoursEnable(false)
-        , mHolidayMask(nullptr)
-        , mWorkingHoursYTop(0)
-        , mWorkingHoursYBottom(0)
-        , mHasSelection(false)
-        , mMarcusBains(nullptr)
-        , mActionType(Agenda::NOP)
-        , mItemMoved(false)
-        , mOldLowerScrollValue(0)
-        , mOldUpperScrollValue(0)
-        , mReturnPressed(false)
         , mIsInteractive(isInteractive)
     {
         if (mGridSpacingY < 4 || mGridSpacingY > 30) {
@@ -222,7 +203,6 @@ public:
         }
     }
 
-public:
     PrefsPtr preferences() const
     {
         return mAgendaView->preferences();
@@ -242,7 +222,7 @@ public:
     AgendaView *mAgendaView = nullptr;
     QScrollArea *mScrollArea = nullptr;
 
-    bool mAllDayMode;
+    bool mAllDayMode{false};
 
     // Number of Columns/Rows of agenda grid
     int mColumns;
@@ -251,19 +231,19 @@ public:
     // Width and height of agenda cells. mDesiredGridSpacingY is the height
     // set in the config. The actual height might be larger since otherwise
     // more than 24 hours might be displayed.
-    double mGridSpacingX;
+    double mGridSpacingX{0.0};
     double mGridSpacingY;
     double mDesiredGridSpacingY;
 
     Akonadi::IncidenceChanger *mChanger = nullptr;
 
     // size of border, where mouse action will resize the AgendaItem
-    int mResizeBorderWidth;
+    int mResizeBorderWidth{0};
 
     // size of border, where mouse mve will cause a scroll of the agenda
-    int mScrollBorderWidth;
-    int mScrollDelay;
-    int mScrollOffset;
+    int mScrollBorderWidth{0};
+    int mScrollDelay{0};
+    int mScrollOffset{0};
 
     QTimer mScrollUpTimer;
     QTimer mScrollDownTimer;
@@ -273,13 +253,13 @@ public:
     QPoint mEndCell;
 
     // Working Hour coordinates
-    bool mWorkingHoursEnable;
+    bool mWorkingHoursEnable{false};
     QList<bool> *mHolidayMask = nullptr;
-    int mWorkingHoursYTop;
-    int mWorkingHoursYBottom;
+    int mWorkingHoursYTop{0};
+    int mWorkingHoursYBottom{0};
 
     // Selection
-    bool mHasSelection;
+    bool mHasSelection{false};
     QPoint mSelectionStartPoint;
     QPoint mSelectionStartCell;
     QPoint mSelectionEndCell;
@@ -303,18 +283,17 @@ public:
     // The Marcus Bains Line widget.
     MarcusBains *mMarcusBains = nullptr;
 
-    Agenda::MouseActionType mActionType;
+    Agenda::MouseActionType mActionType{Agenda::NOP};
 
-    bool mItemMoved;
+    bool mItemMoved{false};
 
     // List of all Items contained in agenda
     QList<AgendaItem::QPtr> mItems;
     QList<AgendaItem::QPtr> mItemsToDelete;
 
-    int mOldLowerScrollValue;
-    int mOldUpperScrollValue;
+    int mOldLowerScrollValue{0};
+    int mOldUpperScrollValue{0};
 
-    bool mReturnPressed;
     bool mIsInteractive;
 
     MultiViewCalendar::Ptr mCalendar;
@@ -592,9 +571,9 @@ bool Agenda::eventFilter_drag(QObject *obj, QDropEvent *de)
 
         const QPoint gridPosition = contentsToGrid(dropPosition);
         if (!incidenceUrls.isEmpty()) {
-            Q_EMIT droppedIncidences(incidenceUrls, gridPosition, d->mAllDayMode);
+            Q_EMIT droppedUrlsSignal(incidenceUrls, gridPosition, d->mAllDayMode);
         } else {
-            Q_EMIT droppedIncidences(incidences, gridPosition, d->mAllDayMode);
+            Q_EMIT droppedIncidencesSignal(incidences, gridPosition, d->mAllDayMode);
         }
         return true;
     }
@@ -615,7 +594,8 @@ bool Agenda::eventFilter_wheel(QObject *object, QWheelEvent *e)
     const QPoint pos = e->position().toPoint();
     if ((e->modifiers() & Qt::ShiftModifier) == Qt::ShiftModifier) {
         if (object != this) {
-            viewportPos = ((QWidget *)object)->mapToParent(pos);
+            const QWidget *w = static_cast<QWidget *>(object);
+            viewportPos = w->mapToParent(pos);
         } else {
             viewportPos = pos;
         }
@@ -626,7 +606,8 @@ bool Agenda::eventFilter_wheel(QObject *object, QWheelEvent *e)
 
     if ((e->modifiers() & Qt::ControlModifier) == Qt::ControlModifier) {
         if (object != this) {
-            viewportPos = ((QWidget *)object)->mapToParent(pos);
+            const QWidget *w = static_cast<QWidget *>(object);
+            viewportPos = w->mapToParent(pos);
         } else {
             viewportPos = pos;
         }
@@ -666,9 +647,9 @@ bool Agenda::eventFilter_mouse(QObject *object, QMouseEvent *me)
                     Q_EMIT showIncidencePopupSignal(d->mClickedItem->incidence(), d->mClickedItem->occurrenceDate());
                 }
             } else {
-                AgendaItem::QPtr item = qobject_cast<AgendaItem *>(object);
+                AgendaItem::QPtr const item = qobject_cast<AgendaItem *>(object);
                 if (item) {
-                    KCalendarCore::Incidence::Ptr incidence = item->incidence();
+                    KCalendarCore::Incidence::Ptr const incidence = item->incidence();
                     if (incidence->isReadOnly()) {
                         d->mActionItem = nullptr;
                     } else {
@@ -685,7 +666,7 @@ bool Agenda::eventFilter_mouse(QObject *object, QMouseEvent *me)
         } else {
             if (me->button() == Qt::RightButton) {
                 // if mouse pointer is not in selection, select the cell below the cursor
-                QPoint gpos = contentsToGrid(viewportPos);
+                QPoint const gpos = contentsToGrid(viewportPos);
                 if (!ptInSelection(gpos)) {
                     d->mSelectionStartCell = gpos;
                     d->mSelectionEndCell = gpos;
@@ -727,8 +708,8 @@ bool Agenda::eventFilter_mouse(QObject *object, QMouseEvent *me)
         // avoid an offset of a few pixels. Don't ask me why...
         QPoint indicatorPos = gridToContents(contentsToGrid(viewportPos));
         if (object != this) {
-            AgendaItem::QPtr moveItem = qobject_cast<AgendaItem *>(object);
-            KCalendarCore::Incidence::Ptr incidence = moveItem ? moveItem->incidence() : KCalendarCore::Incidence::Ptr();
+            AgendaItem::QPtr const moveItem = qobject_cast<AgendaItem *>(object);
+            KCalendarCore::Incidence::Ptr const incidence = moveItem ? moveItem->incidence() : KCalendarCore::Incidence::Ptr();
             if (incidence && !incidence->isReadOnly()) {
                 if (!d->mActionItem) {
                     setNoActionCursor(moveItem, viewportPos);
@@ -769,7 +750,7 @@ bool Agenda::eventFilter_mouse(QObject *object, QMouseEvent *me)
             selectItem(nullptr);
             Q_EMIT newEventSignal();
         } else {
-            AgendaItem::QPtr doubleClickedItem = qobject_cast<AgendaItem *>(object);
+            AgendaItem::QPtr const doubleClickedItem = qobject_cast<AgendaItem *>(object);
             if (doubleClickedItem) {
                 selectItem(doubleClickedItem);
                 Q_EMIT editIncidenceSignal(doubleClickedItem->incidence());
@@ -786,6 +767,7 @@ bool Agenda::eventFilter_mouse(QObject *object, QMouseEvent *me)
 
 bool Agenda::ptInSelection(QPoint gpos) const
 {
+    // NOLINTBEGIN(bugprone-branch-clone)
     if (!d->mHasSelection) {
         return false;
     } else if (gpos.x() < d->mSelectionStartCell.x() || gpos.x() > d->mSelectionEndCell.x()) {
@@ -796,6 +778,7 @@ bool Agenda::ptInSelection(QPoint gpos) const
         return false;
     }
     return true;
+    // NOLINTEND(bugprone-branch-clone)
 }
 
 void Agenda::startSelectAction(QPoint viewportPos)
@@ -806,8 +789,8 @@ void Agenda::startSelectAction(QPoint viewportPos)
     d->mSelectionStartPoint = viewportPos;
     d->mHasSelection = true;
 
-    QPoint pos = viewportPos;
-    QPoint gpos = contentsToGrid(pos);
+    QPoint const pos = viewportPos;
+    QPoint const gpos = contentsToGrid(pos);
 
     // Store new selection
     d->mStartCell = gpos;
@@ -847,7 +830,7 @@ void Agenda::performSelectAction(QPoint pos)
     }
 }
 
-void Agenda::endSelectAction(const QPoint &currentPos)
+void Agenda::endSelectAction(const QPoint &viewportPos)
 {
     d->mScrollUpTimer.stop();
     d->mScrollDownTimer.stop();
@@ -857,7 +840,7 @@ void Agenda::endSelectAction(const QPoint &currentPos)
     Q_EMIT newTimeSpanSignal(d->mSelectionStartCell, d->mSelectionEndCell);
 
     if (d->preferences()->selectionStartsEditor()) {
-        if ((d->mSelectionStartPoint - currentPos).manhattanLength() > QApplication::startDragDistance()) {
+        if ((d->mSelectionStartPoint - viewportPos).manhattanLength() > QApplication::startDragDistance()) {
             Q_EMIT newEventSignal();
         }
     }
@@ -868,18 +851,18 @@ Agenda::MouseActionType Agenda::isInResizeArea(bool horizontal, QPoint pos, cons
     if (!item) {
         return NOP;
     }
-    QPoint gridpos = contentsToGrid(pos);
-    QPoint contpos = gridToContents(gridpos + QPoint((QApplication::isRightToLeft()) ? 1 : 0, 0));
+    QPoint const gridpos = contentsToGrid(pos);
+    QPoint const contpos = gridToContents(gridpos + QPoint((QApplication::isRightToLeft()) ? 1 : 0, 0));
 
     if (horizontal) {
         int clXLeft = item->cellXLeft();
         int clXRight = item->cellXRight();
         if (QApplication::isRightToLeft()) {
-            int tmp = clXLeft;
+            int const tmp = clXLeft;
             clXLeft = clXRight;
             clXRight = tmp;
         }
-        int gridDistanceX = int(pos.x() - contpos.x());
+        int const gridDistanceX = int(pos.x() - contpos.x());
         if (gridDistanceX < d->mResizeBorderWidth && clXLeft == gridpos.x()) {
             if (QApplication::isRightToLeft()) {
                 return RESIZERIGHT;
@@ -896,7 +879,7 @@ Agenda::MouseActionType Agenda::isInResizeArea(bool horizontal, QPoint pos, cons
             return MOVE;
         }
     } else {
-        int gridDistanceY = int(pos.y() - contpos.y());
+        int const gridDistanceY = int(pos.y() - contpos.y());
         if (gridDistanceY < d->mResizeBorderWidth && item->cellYTop() == gridpos.y() && !item->firstMultiItem()) {
             return RESIZETOP;
         } else if ((d->mGridSpacingY - gridDistanceY) < d->mResizeBorderWidth && item->cellYBottom() == gridpos.y() && !item->lastMultiItem()) {
@@ -914,7 +897,7 @@ void Agenda::startItemAction(const QPoint &pos)
     d->mStartCell = contentsToGrid(pos);
     d->mEndCell = d->mStartCell;
 
-    bool noResize = CalendarSupport::hasTodo(d->mActionItem->incidence());
+    bool const noResize = CalendarSupport::hasTodo(d->mActionItem->incidence());
 
     d->mActionType = MOVE;
     if (!noResize) {
@@ -927,7 +910,7 @@ void Agenda::startItemAction(const QPoint &pos)
 
 void Agenda::performItemAction(QPoint pos)
 {
-    QPoint gpos = contentsToGrid(pos);
+    QPoint const gpos = contentsToGrid(pos);
 
     // Cursor left active agenda area.
     // This starts a drag.
@@ -969,8 +952,9 @@ void Agenda::performItemAction(QPoint pos)
         if (!d->mItemMoved) {
             if (!d->mChanger) {
                 KMessageBox::information(this,
-                                         i18n("Unable to lock item for modification. "
-                                              "You cannot make any changes."),
+                                         i18nc("@info",
+                                               "Unable to lock item for modification. "
+                                               "You cannot make any changes."),
                                          i18nc("@title:window", "Locking Failed"),
                                          QStringLiteral("AgendaLockingFailed"));
                 d->mScrollUpTimer.stop();
@@ -998,7 +982,7 @@ void Agenda::performItemAction(QPoint pos)
             if (!lastItem) {
                 lastItem = d->mActionItem;
             }
-            QPoint deltapos = gpos - d->mEndCell;
+            QPoint const deltapos = gpos - d->mEndCell;
             AgendaItem::QPtr moveItem = firstItem;
             while (moveItem) {
                 bool changed = false;
@@ -1008,7 +992,7 @@ void Agenda::performItemAction(QPoint pos)
                 }
                 // in all day view don't try to move multi items, since there are none
                 if (moveItem == firstItem && !d->mAllDayMode) { // is the first item
-                    int newY = deltapos.y() + moveItem->cellYTop();
+                    int const newY = deltapos.y() + moveItem->cellYTop();
                     // If event start moved earlier than 0:00, it starts the previous day
                     if (newY < 0 && newY > d->mScrollBorderWidth) {
                         moveItem->expandTop(-moveItem->cellYTop());
@@ -1020,7 +1004,7 @@ void Agenda::performItemAction(QPoint pos)
                             newFirst->setCellXY(moveItem->cellXLeft() - 1, rows() + newY, rows() - 1);
                             d->mItems.append(newFirst);
                             moveItem->resize(int(d->mGridSpacingX * newFirst->cellWidth()), int(d->mGridSpacingY * newFirst->cellHeight()));
-                            QPoint cpos = gridToContents(QPoint(newFirst->cellXLeft(), newFirst->cellYTop()));
+                            QPoint const cpos = gridToContents(QPoint(newFirst->cellXLeft(), newFirst->cellYTop()));
                             newFirst->setParent(this);
                             newFirst->move(cpos.x(), cpos.y());
                         } else {
@@ -1057,7 +1041,7 @@ void Agenda::performItemAction(QPoint pos)
                     changed = true;
                 }
                 if (moveItem && !moveItem->lastMultiItem() && !d->mAllDayMode) { // is the last item
-                    int newY = deltapos.y() + moveItem->cellYBottom();
+                    int const newY = deltapos.y() + moveItem->cellYBottom();
                     if (newY < 0) {
                         // erase current item
                         lastItem = moveItem->prevMultiItem();
@@ -1075,7 +1059,7 @@ void Agenda::performItemAction(QPoint pos)
                             newLast->setCellXY(moveItem->cellXLeft() + 1, 0, newY - rows() - 1);
                             d->mItems.append(newLast);
                             moveItem->resize(int(d->mGridSpacingX * newLast->cellWidth()), int(d->mGridSpacingY * newLast->cellHeight()));
-                            QPoint cpos = gridToContents(QPoint(newLast->cellXLeft(), newLast->cellYTop()));
+                            QPoint const cpos = gridToContents(QPoint(newLast->cellXLeft(), newLast->cellYTop()));
                             newLast->setParent(this);
                             newLast->move(cpos.x(), cpos.y());
                         } else {
@@ -1157,7 +1141,7 @@ void Agenda::endItemAction()
         // get the main event and not the exception
         if (incidence->hasRecurrenceId() && !incidence->recurs()) {
             KCalendarCore::Incidence::Ptr mainIncidence;
-            KCalendarCore::Calendar::Ptr cal = d->mCalendar->findCalendar(incidence)->getCalendar();
+            KCalendarCore::Calendar::Ptr const cal = d->mCalendar->findCalendar(incidence)->getCalendar();
             if (CalendarSupport::hasEvent(incidence)) {
                 mainIncidence = cal->event(incidence->uid());
             } else if (CalendarSupport::hasTodo(incidence)) {
@@ -1186,11 +1170,11 @@ void Agenda::endItemAction()
                 const bool thisAndFuture = (res == KCalUtils::RecurrenceActions::FutureOccurrences);
                 modify = true;
                 multiModify = true;
-                d->mChanger->startAtomicOperation(i18n("Dissociate event from recurrence"));
-                KCalendarCore::Incidence::Ptr newInc(KCalendarCore::Calendar::createException(incidence, recurrenceId, thisAndFuture));
+                d->mChanger->startAtomicOperation(i18nc("@info/plain", "Dissociate event from recurrence"));
+                KCalendarCore::Incidence::Ptr const newInc(KCalendarCore::Calendar::createException(incidence, recurrenceId, thisAndFuture));
                 if (newInc) {
                     newInc->removeCustomProperty("VOLATILE", "AKONADI-ID");
-                    Akonadi::Item newItem = d->mCalendar->item(newInc);
+                    Akonadi::Item const newItem = d->mCalendar->item(newInc);
 
                     if (newItem.isValid() && newItem != item) { // it is not a new exception
                         item = newItem;
@@ -1203,13 +1187,14 @@ void Agenda::endItemAction()
                     d->mAgendaView->enableAgendaUpdate(false);
 
                     d->mActionItem->setIncidence(newInc);
-                    d->mActionItem->dissociateFromMultiItem();
+                    (void)d->mActionItem->dissociateFromMultiItem(); // returns false if not a multi-item. we don't care in this case
 
                     d->mAgendaView->enableAgendaUpdate(true);
                 } else {
                     KMessageBox::error(this,
-                                       i18n("Unable to add the exception item to the calendar. "
-                                            "No change will be done."),
+                                       i18nc("@info",
+                                             "Unable to add the exception item to the calendar. "
+                                             "No change will be done."),
                                        i18nc("@title:window", "Error Occurred"));
                 }
                 break;
@@ -1241,7 +1226,7 @@ void Agenda::endItemAction()
         if (modify) {
             d->mActionItem->endMove();
 
-            AgendaItem::QPtr modif = placeItem;
+            AgendaItem::QPtr const modif = placeItem;
 
             QList<AgendaItem::QPtr> oldconflictItems = placeItem->conflictItems();
             QList<AgendaItem::QPtr>::iterator it;
@@ -1333,7 +1318,7 @@ double Agenda::calcSubCellWidth(const AgendaItem::QPtr &item)
     pt = gridToContents(QPoint(item->cellXLeft(), item->cellYTop()));
     pt1 = gridToContents(QPoint(item->cellXLeft(), item->cellYTop()) + QPoint(1, 1));
     pt1 -= pt;
-    int maxSubCells = item->subCells();
+    int const maxSubCells = item->subCells();
     double newSubCellWidth;
     if (d->mAllDayMode) {
         newSubCellWidth = static_cast<double>(pt1.y()) / maxSubCells;
@@ -1353,7 +1338,7 @@ void Agenda::adjustItemPosition(const AgendaItem::QPtr &item)
     if (QApplication::isRightToLeft()) {
         clXLeft = item->cellXRight() + 1;
     }
-    QPoint cpos = gridToContents(QPoint(clXLeft, item->cellYTop()));
+    QPoint const cpos = gridToContents(QPoint(clXLeft, item->cellYTop()));
     item->move(cpos.x(), cpos.y());
 }
 
@@ -1361,11 +1346,11 @@ void Agenda::placeAgendaItem(const AgendaItem::QPtr &item, double subCellWidth)
 {
     // "left" upper corner, no subcells yet, RTL layouts have right/left
     // switched, widths are negative then
-    QPoint pt = gridToContents(QPoint(item->cellXLeft(), item->cellYTop()));
+    QPoint const pt = gridToContents(QPoint(item->cellXLeft(), item->cellYTop()));
     // right lower corner
-    QPoint pt1 = gridToContents(QPoint(item->cellXLeft() + item->cellWidth(), item->cellYBottom() + 1));
+    QPoint const pt1 = gridToContents(QPoint(item->cellXLeft() + item->cellWidth(), item->cellYBottom() + 1));
 
-    double subCellPos = item->subCell() * subCellWidth;
+    double const subCellPos = item->subCell() * subCellWidth;
 
     // we need to add 0.01 to make sure we don't loose one pixed due to numerics
     // (i.e. if it would be x.9998, we want the integer, not rounded down.
@@ -1412,21 +1397,6 @@ void Agenda::placeAgendaItem(const AgendaItem::QPtr &item, double subCellWidth)
 */
 void Agenda::placeSubCells(const AgendaItem::QPtr &placeItem)
 {
-#if 0
-    qCDebug(CALENDARVIEW_LOG);
-    if (placeItem) {
-        KCalendarCore::Incidence::Ptr event = placeItem->incidence();
-        if (!event) {
-            qCDebug(CALENDARVIEW_LOG) << "  event is 0";
-        } else {
-            qCDebug(CALENDARVIEW_LOG) << "  event:" << event->summary();
-        }
-    } else {
-        qCDebug(CALENDARVIEW_LOG) << "  placeItem is 0";
-    }
-    qCDebug(CALENDARVIEW_LOG) << "Agenda::placeSubCells()...";
-#endif
-
     QList<CalendarSupport::CellItem *> cells;
     for (CalendarSupport::CellItem *item : std::as_const(d->mItems)) {
         if (item) {
@@ -1437,11 +1407,11 @@ void Agenda::placeSubCells(const AgendaItem::QPtr &placeItem)
     QList<CalendarSupport::CellItem *> items = CalendarSupport::CellItem::placeItem(cells, placeItem);
 
     placeItem->setConflictItems(QList<AgendaItem::QPtr>());
-    double newSubCellWidth = calcSubCellWidth(placeItem);
+    double const newSubCellWidth = calcSubCellWidth(placeItem);
     QList<CalendarSupport::CellItem *>::iterator it;
     for (it = items.begin(); it != items.end(); ++it) {
         if (*it) {
-            AgendaItem::QPtr item = static_cast<AgendaItem *>(*it);
+            AgendaItem::QPtr const item = static_cast<AgendaItem *>(*it);
             placeAgendaItem(item, newSubCellWidth);
             item->addConflictItem(placeItem);
             placeItem->addConflictItem(item);
@@ -1455,13 +1425,13 @@ void Agenda::placeSubCells(const AgendaItem::QPtr &placeItem)
 
 int Agenda::columnWidth(int column) const
 {
-    int start = gridToContents(QPoint(column, 0)).x();
+    int const start = gridToContents(QPoint(column, 0)).x();
     if (QApplication::isRightToLeft()) {
         column--;
     } else {
         column++;
     }
-    int end = gridToContents(QPoint(column, 0)).x();
+    int const end = gridToContents(QPoint(column, 0)).x();
     return end - start;
 }
 
@@ -1492,7 +1462,7 @@ void Agenda::drawContents(QPainter *p, int cx, int cy, int cw, int ch)
 
     dbp.translate(-cx, -cy);
 
-    double lGridSpacingY = d->mGridSpacingY * 2;
+    double const lGridSpacingY = d->mGridSpacingY * 2;
 
     // If work day, use work color
     // If busy day, use busy color
@@ -1509,21 +1479,21 @@ void Agenda::drawContents(QPainter *p, int cx, int cy, int cw, int ch)
             workColor = palette().color(QPalette::Base);
         }
 
-        QPoint pt1(cx, d->mWorkingHoursYTop);
-        QPoint pt2(cx + cw, d->mWorkingHoursYBottom);
+        QPoint const pt1(cx, d->mWorkingHoursYTop);
+        QPoint const pt2(cx + cw, d->mWorkingHoursYBottom);
         if (pt2.x() >= pt1.x() /*&& pt2.y() >= pt1.y()*/) {
             int gxStart = contentsToGrid(pt1).x();
             int gxEnd = contentsToGrid(pt2).x();
             // correct start/end for rtl layouts
             if (gxStart > gxEnd) {
-                int tmp = gxStart;
+                int const tmp = gxStart;
                 gxStart = gxEnd;
                 gxEnd = tmp;
             }
-            int xoffset = (QApplication::isRightToLeft() ? 1 : 0);
+            int const xoffset = (QApplication::isRightToLeft() ? 1 : 0);
             while (gxStart <= gxEnd) {
-                int xStart = gridToContents(QPoint(gxStart + xoffset, 0)).x();
-                int xWidth = columnWidth(gxStart) + 1;
+                int const xStart = gridToContents(QPoint(gxStart + xoffset, 0)).x();
+                int const xWidth = columnWidth(gxStart) + 1;
 
                 if (pt2.y() < pt1.y()) {
                     // overnight working hours
@@ -1653,8 +1623,8 @@ void Agenda::drawContents(QPainter *p, int cx, int cy, int cw, int ch)
 */
 QPoint Agenda::contentsToGrid(QPoint pos) const
 {
-    int gx = int(QApplication::isRightToLeft() ? d->mColumns - pos.x() / d->mGridSpacingX : pos.x() / d->mGridSpacingX);
-    int gy = int(pos.y() / d->mGridSpacingY);
+    int const gx = int(QApplication::isRightToLeft() ? d->mColumns - pos.x() / d->mGridSpacingX : pos.x() / d->mGridSpacingX);
+    int const gy = int(pos.y() / d->mGridSpacingY);
     return {gx, gy};
 }
 
@@ -1663,8 +1633,8 @@ QPoint Agenda::contentsToGrid(QPoint pos) const
 */
 QPoint Agenda::gridToContents(QPoint gpos) const
 {
-    int x = int(QApplication::isRightToLeft() ? (d->mColumns - gpos.x()) * d->mGridSpacingX : gpos.x() * d->mGridSpacingX);
-    int y = int(gpos.y() * d->mGridSpacingY);
+    int const x = int(QApplication::isRightToLeft() ? (d->mColumns - gpos.x()) * d->mGridSpacingX : gpos.x() * d->mGridSpacingX);
+    int const y = int(gpos.y() * d->mGridSpacingY);
     return {x, y};
 }
 
@@ -1674,9 +1644,9 @@ QPoint Agenda::gridToContents(QPoint gpos) const
 */
 int Agenda::timeToY(QTime time) const
 {
-    int minutesPerCell = 24 * 60 / d->mRows;
-    int timeMinutes = time.hour() * 60 + time.minute();
-    int Y = (timeMinutes + (minutesPerCell / 2)) / minutesPerCell;
+    int const minutesPerCell = 24 * 60 / d->mRows;
+    int const timeMinutes = time.hour() * 60 + time.minute();
+    int const Y = (timeMinutes + (minutesPerCell / 2)) / minutesPerCell;
 
     return Y;
 }
@@ -1687,8 +1657,8 @@ int Agenda::timeToY(QTime time) const
 */
 QTime Agenda::gyToTime(int gy) const
 {
-    int secondsPerCell = 24 * 60 * 60 / d->mRows;
-    int timeSeconds = secondsPerCell * gy;
+    int const secondsPerCell = 24 * 60 * 60 / d->mRows;
+    int const timeSeconds = secondsPerCell * gy;
 
     QTime time(0, 0, 0);
     if (timeSeconds < 24 * 60 * 60) {
@@ -1705,8 +1675,8 @@ QList<int> Agenda::minContentsY() const
     minArray.fill(timeToY(QTime(23, 59)), d->mSelectedDates.count());
     for (const AgendaItem::QPtr &item : std::as_const(d->mItems)) {
         if (item) {
-            int ymin = item->cellYTop();
-            int index = item->cellXLeft();
+            int const ymin = item->cellYTop();
+            int const index = item->cellXLeft();
             if (index >= 0 && index < (int)(d->mSelectedDates.count())) {
                 if (ymin < minArray[index] && !d->mItemsToDelete.contains(item)) {
                     minArray[index] = ymin;
@@ -1724,9 +1694,9 @@ QList<int> Agenda::maxContentsY() const
     maxArray.fill(timeToY(QTime(0, 0)), d->mSelectedDates.count());
     for (const AgendaItem::QPtr &item : std::as_const(d->mItems)) {
         if (item) {
-            int ymax = item->cellYBottom();
+            int const ymax = item->cellYBottom();
 
-            int index = item->cellXLeft();
+            int const index = item->cellXLeft();
             if (index >= 0 && index < (int)(d->mSelectedDates.count())) {
                 if (ymax > maxArray[index] && !d->mItemsToDelete.contains(item)) {
                     maxArray[index] = ymax;
@@ -1860,7 +1830,7 @@ void Agenda::insertMultiItem(const KCalendarCore::Incidence::Ptr &event,
                              int YBottom,
                              bool isSelected)
 {
-    KCalendarCore::Event::Ptr ev = CalendarSupport::event(event);
+    KCalendarCore::Event::Ptr const ev = CalendarSupport::event(event);
     Q_ASSERT(ev);
     if (d->mAllDayMode) {
         qCDebug(CALENDARVIEW_LOG) << "using this in all-day mode is illegal.";
@@ -1872,11 +1842,11 @@ void Agenda::insertMultiItem(const KCalendarCore::Incidence::Ptr &event,
     int cellYTop;
     int cellYBottom;
     QString newtext;
-    int width = XEnd - XBegin + 1;
+    int const width = XEnd - XBegin + 1;
     int count = 0;
     AgendaItem::QPtr current = nullptr;
     QList<AgendaItem::QPtr> multiItems;
-    int visibleCount = d->mSelectedDates.first().daysTo(d->mSelectedDates.last());
+    int const visibleCount = d->mSelectedDates.first().daysTo(d->mSelectedDates.last());
     for (cellX = XBegin; cellX <= XEnd; ++cellX) {
         ++count;
         // Only add the items that are visible.
@@ -1894,7 +1864,7 @@ void Agenda::insertMultiItem(const KCalendarCore::Incidence::Ptr &event,
             newtext = QStringLiteral("(%1/%2): ").arg(count).arg(width);
             newtext.append(ev->summary());
 
-            current = insertItem(event, recurrenceId, cellX, cellYTop, cellYBottom, count, width, isSelected);
+            current = insertItem(event, recurrenceId, cellX, cellYTop, cellYBottom, width, count, isSelected);
             Q_ASSERT(current);
             current->setText(newtext);
             multiItems.append(current);
@@ -1902,16 +1872,16 @@ void Agenda::insertMultiItem(const KCalendarCore::Incidence::Ptr &event,
     }
 
     QList<AgendaItem::QPtr>::iterator it = multiItems.begin();
-    QList<AgendaItem::QPtr>::iterator e = multiItems.end();
+    QList<AgendaItem::QPtr>::iterator const e = multiItems.end();
 
     if (it != e) { // .first asserts if the list is empty
-        AgendaItem::QPtr first = multiItems.first();
-        AgendaItem::QPtr last = multiItems.last();
+        const AgendaItem::QPtr &first = multiItems.first();
+        const AgendaItem::QPtr &last = multiItems.last();
         AgendaItem::QPtr prev = nullptr;
         AgendaItem::QPtr next = nullptr;
 
         while (it != e) {
-            AgendaItem::QPtr item = *it;
+            AgendaItem::QPtr const item = *it;
             ++it;
             next = (it == e) ? nullptr : (*it);
             if (item) {
@@ -1935,13 +1905,11 @@ void Agenda::removeIncidence(const KCalendarCore::Incidence::Ptr &incidence)
         return; // It's already queued for deletion
     }
 
-    const AgendaItem::List agendaItems = d->mAgendaItemsById.values(incidence->uid());
-    if (agendaItems.isEmpty()) {
-        // We're not displaying such item
-        // qCDebug(CALENDARVIEW_LOG) << "Ignoring";
+    const AgendaItem::List agendaItemList = d->mAgendaItemsById.values(incidence->uid());
+    if (agendaItemList.isEmpty()) {
         return;
     }
-    for (const AgendaItem::QPtr &agendaItem : agendaItems) {
+    for (const AgendaItem::QPtr &agendaItem : agendaItemList) {
         if (agendaItem) {
             if (incidence->instanceIdentifier() != agendaItem->incidence()->instanceIdentifier()) {
                 continue;
@@ -1979,7 +1947,7 @@ bool Agenda::removeAgendaItem(const AgendaItem::QPtr &agendaItem)
     QList<AgendaItem::QPtr> conflictItems = agendaItem->conflictItems();
     // removeChild(thisItem);
 
-    bool taken = d->mItems.removeAll(agendaItem) > 0;
+    bool const taken = d->mItems.removeAll(agendaItem) > 0;
     d->mAgendaItemsById.remove(agendaItem->incidence()->uid(), agendaItem);
 
     QList<AgendaItem::QPtr>::iterator it;
@@ -2028,7 +1996,7 @@ void Agenda::deleteItemsToDelete()
 */
 void Agenda::resizeEvent(QResizeEvent *ev)
 {
-    QSize newSize(ev->size());
+    QSize const newSize(ev->size());
 
     if (d->mAllDayMode) {
         d->mGridSpacingX = static_cast<double>(newSize.width()) / d->mColumns;
@@ -2083,13 +2051,13 @@ void Agenda::resizeAllContents()
 
 void Agenda::scrollUp()
 {
-    int currentValue = verticalScrollBar()->value();
+    int const currentValue = verticalScrollBar()->value();
     verticalScrollBar()->setValue(currentValue - d->mScrollOffset);
 }
 
 void Agenda::scrollDown()
 {
-    int currentValue = verticalScrollBar()->value();
+    int const currentValue = verticalScrollBar()->value();
     verticalScrollBar()->setValue(currentValue + d->mScrollOffset);
 }
 
@@ -2156,8 +2124,8 @@ void Agenda::checkScrollBoundaries()
 
 void Agenda::checkScrollBoundaries(int v)
 {
-    int yMin = int((v) / d->mGridSpacingY);
-    int yMax = int((v + d->mScrollArea->height()) / d->mGridSpacingY);
+    int const yMin = int((v) / d->mGridSpacingY);
+    int const yMax = int((v + d->mScrollArea->height()) / d->mGridSpacingY);
 
     if (yMin != d->mOldLowerScrollValue) {
         d->mOldLowerScrollValue = yMin;
@@ -2171,13 +2139,13 @@ void Agenda::checkScrollBoundaries(int v)
 
 int Agenda::visibleContentsYMin() const
 {
-    int v = verticalScrollBar()->value();
+    int const v = verticalScrollBar()->value();
     return int(v / d->mGridSpacingY);
 }
 
 int Agenda::visibleContentsYMax() const
 {
-    int v = verticalScrollBar()->value();
+    int const v = verticalScrollBar()->value();
     return int((v + d->mScrollArea->height()) / d->mGridSpacingY);
 }
 
@@ -2189,7 +2157,7 @@ void Agenda::deselectItem()
 
     const KCalendarCore::Incidence::Ptr selectedItem = d->mSelectedItem->incidence();
 
-    for (AgendaItem::QPtr item : std::as_const(d->mItems)) {
+    for (const AgendaItem::QPtr &item : std::as_const(d->mItems)) {
         if (item) {
             const KCalendarCore::Incidence::Ptr itemInc = item->incidence();
             if (itemInc && selectedItem && itemInc->uid() == selectedItem->uid()) {
@@ -2216,9 +2184,9 @@ void Agenda::selectItem(const AgendaItem::QPtr &item)
     Q_ASSERT(d->mSelectedItem->incidence());
     d->mSelectedId = d->mSelectedItem->incidence()->uid();
 
-    for (AgendaItem::QPtr item : std::as_const(d->mItems)) {
-        if (item && item->incidence()->uid() == d->mSelectedId) {
-            item->select();
+    for (const AgendaItem::QPtr &agendaItem : std::as_const(d->mItems)) {
+        if (agendaItem && agendaItem->incidence()->uid() == d->mSelectedId) {
+            agendaItem->select();
         }
     }
     Q_EMIT incidenceSelected(d->mSelectedItem->incidence(), d->mSelectedItem->occurrenceDate());
