@@ -18,7 +18,7 @@
 #include <QRandomGenerator>
 using namespace EventViews;
 
-QSet<EventViews::EventView::ItemIcon> iconArrayToSet(const QByteArray &array)
+static QSet<EventViews::EventView::ItemIcon> iconArrayToSet(const QByteArray &array)
 {
     QSet<EventViews::EventView::ItemIcon> set;
     for (int i = 0; i < array.size(); ++i) {
@@ -33,7 +33,7 @@ QSet<EventViews::EventView::ItemIcon> iconArrayToSet(const QByteArray &array)
     return set;
 }
 
-QByteArray iconSetToArray(const QSet<EventViews::EventView::ItemIcon> &set)
+static QByteArray iconSetToArray(const QSet<EventViews::EventView::ItemIcon> &set)
 {
     QByteArray array;
     for (int i = 0; i < EventViews::EventView::IconCount; ++i) {
@@ -44,7 +44,7 @@ QByteArray iconSetToArray(const QSet<EventViews::EventView::ItemIcon> &set)
     return array;
 }
 
-QByteArray agendaViewIconDefaults()
+static QByteArray agendaViewIconDefaults()
 {
     QByteArray iconDefaults;
     iconDefaults.resize(7);
@@ -60,7 +60,7 @@ QByteArray agendaViewIconDefaults()
     return iconDefaults;
 }
 
-QByteArray monthViewIconDefaults()
+static QByteArray monthViewIconDefaults()
 {
     QByteArray iconDefaults;
     iconDefaults.resize(7);
@@ -85,8 +85,9 @@ public:
 
     void setTimeScaleTimezones(const QStringList &timeZones);
     QStringList timeScaleTimezones() const;
+    void setUse24HourClock(bool enable);
+    bool use24HourClock() const;
 
-public:
     QHash<QString, QColor> mResourceColors;
     QColor mDefaultResourceColor;
 
@@ -94,6 +95,7 @@ public:
     QFont mDefaultAgendaTimeLabelsFont;
 
     QStringList mTimeScaleTimeZones;
+    bool mUse24HourClock = false;
 
     QSet<EventViews::EventView::ItemIcon> mAgendaViewIcons;
     QSet<EventViews::EventView::ItemIcon> mMonthViewIcons;
@@ -105,15 +107,12 @@ protected:
 };
 
 BaseConfig::BaseConfig()
-    : PrefsBase()
+    : mDefaultMonthViewFont(QFontDatabase::systemFont(QFontDatabase::GeneralFont))
+    , mDefaultAgendaTimeLabelsFont(QFontDatabase::systemFont(QFontDatabase::GeneralFont))
 {
-    mDefaultResourceColor = QColor(); // Default is a color invalid
-
-    mDefaultAgendaTimeLabelsFont = QFontDatabase::systemFont(QFontDatabase::GeneralFont);
     // make a large default time bar font, at least 16 points.
     mDefaultAgendaTimeLabelsFont.setPointSize(qMax(mDefaultAgendaTimeLabelsFont.pointSize() + 4, 16));
 
-    mDefaultMonthViewFont = QFontDatabase::systemFont(QFontDatabase::GeneralFont);
     // make it a bit smaller
     mDefaultMonthViewFont.setPointSize(qMax(mDefaultMonthViewFont.pointSize() - 2, 6));
 
@@ -128,9 +127,9 @@ void BaseConfig::setResourceColor(const QString &resource, const QColor &color)
     mResourceColors.insert(resource, color);
 }
 
-void BaseConfig::setTimeScaleTimezones(const QStringList &list)
+void BaseConfig::setTimeScaleTimezones(const QStringList &timeZones)
 {
-    mTimeScaleTimeZones = list;
+    mTimeScaleTimeZones = timeZones;
 }
 
 QStringList BaseConfig::timeScaleTimezones() const
@@ -138,6 +137,16 @@ QStringList BaseConfig::timeScaleTimezones() const
     return mTimeScaleTimeZones;
 }
 
+void BaseConfig::setUse24HourClock(bool enable)
+{
+    mUse24HourClock = enable;
+}
+
+bool BaseConfig::use24HourClock() const
+{
+    return mUse24HourClock;
+}
+
 void BaseConfig::usrSetDefaults()
 {
     setAgendaTimeLabelsFont(mDefaultAgendaTimeLabelsFont);
@@ -148,28 +157,28 @@ void BaseConfig::usrSetDefaults()
 
 void BaseConfig::usrRead()
 {
-    KConfigGroup rColorsConfig(config(), QStringLiteral("Resources Colors"));
+    KConfigGroup const rColorsConfig(config(), QStringLiteral("Resources Colors"));
     const QStringList colorKeyList = rColorsConfig.keyList();
 
     for (const QString &key : colorKeyList) {
-        QColor color = rColorsConfig.readEntry(key, mDefaultResourceColor);
+        QColor const color = rColorsConfig.readEntry(key, mDefaultResourceColor);
         // qCDebug(CALENDARVIEW_LOG) << "key:" << key << "value:" << color;
         setResourceColor(key, color);
     }
 
-#if 0
-    config()->setGroup("FreeBusy");
-    if (mRememberRetrievePw) {
-        mRetrievePassword
-            = KStringHandler::obscure(config()->readEntry("Retrieve Server Password"));
-    }
-#endif
-
-    KConfigGroup timeScaleConfig(config(), QStringLiteral("Timescale"));
+    KConfigGroup const timeScaleConfig(config(), QStringLiteral("Timescale"));
     setTimeScaleTimezones(timeScaleConfig.readEntry("Timescale Timezones", QStringList()));
+    const QString str = QLocale().timeFormat();
+    // 'A' or 'a' means am/pm is shown (and then 'h' uses 12-hour format)
+    // but 'H' forces a 24-hour format anyway, even with am/pm shown.
+    if (str.contains(QLatin1Char('a'), Qt::CaseInsensitive) && !str.contains(QLatin1Char('H'))) {
+        setUse24HourClock(timeScaleConfig.readEntry("24 Hour Clock", false));
+    } else {
+        setUse24HourClock(timeScaleConfig.readEntry("24 Hour Clock", true));
+    }
 
-    KConfigGroup monthViewConfig(config(), QStringLiteral("Month View"));
-    KConfigGroup agendaViewConfig(config(), QStringLiteral("Agenda View"));
+    KConfigGroup const monthViewConfig(config(), QStringLiteral("Month View"));
+    KConfigGroup const agendaViewConfig(config(), QStringLiteral("Agenda View"));
     const auto agendaIconArray = agendaViewConfig.readEntry<QByteArray>("agendaViewItemIcons", agendaViewIconDefaults());
     const auto monthIconArray = monthViewConfig.readEntry<QByteArray>("monthViewItemIcons", monthViewIconDefaults());
 
@@ -186,17 +195,9 @@ bool BaseConfig::usrSave()
         rColorsConfig.writeEntry(it.key(), it.value());
     }
 
-#if 0
-    if (mRememberRetrievePw) {
-        config()->writeEntry("Retrieve Server Password",
-                             KStringHandler::obscure(mRetrievePassword));
-    } else {
-        config()->deleteEntry("Retrieve Server Password");
-    }
-#endif
-
     KConfigGroup timeScaleConfig(config(), QStringLiteral("Timescale"));
     timeScaleConfig.writeEntry("Timescale Timezones", timeScaleTimezones());
+    timeScaleConfig.writeEntry("24 Hour Clock", use24HourClock());
 
     KConfigGroup monthViewConfig(config(), QStringLiteral("Month View"));
     KConfigGroup agendaViewConfig(config(), QStringLiteral("Agenda View"));
@@ -213,15 +214,12 @@ bool BaseConfig::usrSave()
 class EventViews::PrefsPrivate
 {
 public:
-    explicit PrefsPrivate(Prefs *parent)
-        : mAppConfig(nullptr)
-        , q(parent)
+    explicit PrefsPrivate()
     {
     }
 
-    PrefsPrivate(Prefs *parent, KCoreConfigSkeleton *appConfig)
+    explicit PrefsPrivate(KCoreConfigSkeleton *appConfig)
         : mAppConfig(appConfig)
-        , q(parent)
     {
     }
 
@@ -248,12 +246,8 @@ public:
     void setFont(KConfigSkeleton::ItemFont *baseConfigItem, const QFont &value);
     QFont getFont(const KConfigSkeleton::ItemFont *baseConfigItem) const;
 
-public:
     BaseConfig mBaseConfig;
     KCoreConfigSkeleton *mAppConfig = nullptr;
-
-private:
-    Prefs *q;
 };
 
 KConfigSkeletonItem *PrefsPrivate::appConfigItem(const KConfigSkeletonItem *baseConfigItem) const
@@ -470,14 +464,14 @@ QFont PrefsPrivate::getFont(const KConfigSkeleton::ItemFont *baseConfigItem) con
 }
 
 Prefs::Prefs()
-    : d(new PrefsPrivate(this))
+    : d(new PrefsPrivate())
 {
     // necessary to use CollectionColorAttribute in the EventViews::resourceColor and EventViews::setResourceColor
     Akonadi::AttributeFactory::registerAttribute<Akonadi::CollectionColorAttribute>();
 }
 
 Prefs::Prefs(KCoreConfigSkeleton *appConfig)
-    : d(new PrefsPrivate(this, appConfig))
+    : d(new PrefsPrivate(appConfig))
 {
     // necessary to use CollectionColorAttribute in the EventViews::resourceColor and EventViews::setResourceColor
     Akonadi::AttributeFactory::registerAttribute<Akonadi::CollectionColorAttribute>();
@@ -756,9 +750,9 @@ bool Prefs::showTodosMonthView() const
     return d->getBool(d->mBaseConfig.showTodosMonthViewItem());
 }
 
-void Prefs::setShowTodosMonthView(bool enable)
+void Prefs::setShowTodosMonthView(bool show)
 {
-    d->setBool(d->mBaseConfig.showTodosMonthViewItem(), enable);
+    d->setBool(d->mBaseConfig.showTodosMonthViewItem(), show);
 }
 
 bool Prefs::showJournalsMonthView() const
@@ -766,9 +760,9 @@ bool Prefs::showJournalsMonthView() const
     return d->getBool(d->mBaseConfig.showJournalsMonthViewItem());
 }
 
-void Prefs::setShowJournalsMonthView(bool enable)
+void Prefs::setShowJournalsMonthView(bool show)
 {
-    d->setBool(d->mBaseConfig.showJournalsMonthViewItem(), enable);
+    d->setBool(d->mBaseConfig.showJournalsMonthViewItem(), show);
 }
 
 bool Prefs::fullViewMonth() const
@@ -953,9 +947,19 @@ QStringList Prefs::timeScaleTimezones() const
     return d->mBaseConfig.timeScaleTimezones();
 }
 
-void Prefs::setTimeScaleTimezones(const QStringList &list)
+void Prefs::setTimeScaleTimezones(const QStringList &timeZones)
 {
-    d->mBaseConfig.setTimeScaleTimezones(list);
+    d->mBaseConfig.setTimeScaleTimezones(timeZones);
+}
+
+bool Prefs::use24HourClock() const
+{
+    return d->mBaseConfig.use24HourClock();
+}
+
+void Prefs::setUse24HourClock(bool enable)
+{
+    d->mBaseConfig.setUse24HourClock(enable);
 }
 
 KConfigSkeleton::ItemFont *Prefs::fontItem(const QString &name) const
